@@ -330,7 +330,7 @@ def main():
         main_vbox.pack_start(container, False, False, 0)
         
         check = gtk.CheckButton(_("Notify buddies actions"))
-        tooltips.set_tip(check, _("Buddy logs on and out, is writting or sent a Message"))
+        tooltips.set_tip(check, _("Notify when a contact logs in or out, writes, or sends a message"))
         check.show()
         vbox.pack_start(check, False, False, 0)
         ToggleSync(check, prefs, "enabled")
